import 'package:syncrow_web/pages/analytics/models/range_of_aqi.dart';
import 'package:syncrow_web/pages/analytics/modules/air_quality/widgets/aqi_type_dropdown.dart';
import 'package:syncrow_web/pages/analytics/params/get_range_of_aqi_param.dart';
import 'package:syncrow_web/pages/analytics/services/range_of_aqi/range_of_aqi_service.dart';

class FakeRangeOfAqiService implements RangeOfAqiService {
  @override
  Future<List<RangeOfAqi>> load(GetRangeOfAqiParam param) async {
    return await Future.delayed(const Duration(milliseconds: 800), () {
      final random = DateTime.now().millisecondsSinceEpoch;

      return List.generate(30, (index) {
        final date = DateTime(2025, 5, 1).add(Duration(days: index));

        final min = ((random + index * 17) % 200).toDouble();
        final avgDelta = ((random + index * 23) % 50).toDouble() + 20;
        final maxDelta = ((random + index * 31) % 50).toDouble() + 30;

        final avg = (min + avgDelta).clamp(0.0, 301.0);
        final max = (avg + maxDelta).clamp(0.0, 301.0);

        return RangeOfAqi(  
          data: [
            RangeOfAqiValue(type: AqiType.aqi.code, min: min, average: avg, max: max),
            RangeOfAqiValue(type: AqiType.pm25.code, min: min, average: avg, max: max),
            RangeOfAqiValue(type: AqiType.pm10.code, min: min, average: avg, max: max),
            RangeOfAqiValue(type: AqiType.hcho.code, min: min, average: avg, max: max),
            RangeOfAqiValue(type: AqiType.tvoc.code, min: min, average: avg, max: max),
            RangeOfAqiValue(type: AqiType.co2.code, min: min, average: avg, max: max),
          ],
          date: date,
        );
      });
    });
  }
}
